"""Common filenames and locations for topographic data, meshes and outputs.
Also includes origin for slump scenario.
"""

from os import sep, environ
from os.path import expanduser
from utilities.polygon import read_polygon
import sys

from pmesh.create_mesh import convert_points_from_latlon_to_utm
                
#Making assumptions about the location of scenario data
scenario_dir_name = 'onslow_tsunami_scenario_2006'

"""
# 250m data to be provided
coarsename = 'onshore_250' # get from Neil/Ingo (DEM or topo data)
# 30m data to be provided
finename = 'onshore_30' # get from Neil/Ingo (DEM or topo data) 
"""

# clipping region for fine elevation data
eastingmin = 250000
eastingmax = 305000
northingmin = 7580000
northingmax = 7635000

#swollen/ all data output
basename = 'source'

if sys.platform == 'win32':
    home = environ['INUNDATIONHOME']     #Sandpit's parent dir
else:    
    home = expanduser('~')

#Derive subdirectories and filenames
meshdir = home+sep+scenario_dir_name+sep+'meshes'+sep
datadir = home+sep+scenario_dir_name+sep+'topographies'+sep
outputdir = home+sep+scenario_dir_name+sep+'output'+sep
polygondir = home+sep+scenario_dir_name+sep+'polygons'+sep

meshname = meshdir + basename
"""
coarsedemname = datadir + coarsename
finedemname = datadir + finename
combineddemname = datadir + 'onslow_combined_elevation'
"""

outputname = outputdir + basename  #Used by post processing

#!gauge_filename = outputdir + 'onslow_gauges.xya'
#!gauge_outname = outputdir + 'gauges_max_output.xya'

#Georeferencing
from coordinate_transforms.redfearn import degminsec2decimal_degrees

refzone = 50

#Main Domain of Onslow: first run NB 21/2/06
d0 = [305000, 7635000]
d1 = [280000, 7635000]
d2 = [250000, 7615000]
d3 = [250000, 7590000]
d4 = [310000, 7580000]
d5 = [330000, 7610000]

polyAll = [d0, d1, d2, d3, d4, d5]

#Interior region - Onslow - take 1
i0 = [310000, 7610000]
i1 = [300000, 7610000]
i2 = [300000, 7600000]
i3 = [310000, 7600000]

polyInterior = [i0, i1, i2, i3]

#!slump_origin = [385000.0, 6255000.0] #Absolute UTM
